# Config file for the magics package
# Defines the following variables:
#
#  MAGICS_INCLUDE_DIRS   - include directories
#  MAGICS_DEFINITIONS    - preprocessor definitions
#  MAGICS_LIBRARIES      - libraries to link against
#  MAGICS_FEATURES       - list of enabled features
#  MAGICS_VERSION        - version of the package
#  MAGICS_GIT_SHA1       - Git revision of the package
#  MAGICS_GIT_SHA1_SHORT - short Git revision of the package
#
# Also defines magics third-party library dependencies:
#  MAGICS_TPLS             - package names of  third-party library dependencies
#  MAGICS_TPL_INCLUDE_DIRS - include directories
#  MAGICS_TPL_DEFINITIONS  - preprocessor definitions
#  MAGICS_TPL_LIBRARIES    - libraries to link against

### compute paths

get_filename_component(MAGICS_CMAKE_DIR "${CMAKE_CURRENT_LIST_FILE}" PATH)

set( MAGICS_SELF_INCLUDE_DIRS "/usr/include/magics;/usr/include/terralib;/usr/include/terralib/kernel" )
set( MAGICS_SELF_DEFINITIONS  "_FILE_OFFSET_BITS=64;MAGICS_QT5" )
set( MAGICS_SELF_LIBRARIES    "MagPlus" )

set( MAGICS_TPLS              "grib_api;spot;EXPAT;NetCDF;PNG;Proj4;libemos;PangoCairo" )
set( MAGICS_TPL_INCLUDE_DIRS  "/usr/lib/include;/usr/include;/usr/lib/python3/dist-packages/numpy/core/include;/usr/include/openjpeg-2.1;/usr/include/hdf5/serial;/usr/include/pango-1.0;/usr/include/harfbuzz;/usr/include/cairo;/usr/include/glib-2.0;/usr/lib/arm-linux-gnueabi/glib-2.0/include;/usr/include/pixman-1;/usr/include/freetype2;/usr/include/libpng16" )
set( MAGICS_TPL_DEFINITIONS   "" )
set( MAGICS_TPL_LIBRARIES     "eccodes;eccodes_f90;/usr/lib/arm-linux-gnueabi/libpng.so;/usr/lib/arm-linux-gnueabi/libz.so;/usr/lib/arm-linux-gnueabi/libaec.so;/usr/lib/arm-linux-gnueabi/libm.so;/usr/lib/arm-linux-gnueabi/libopenjp2.so;/usr/lib/arm-linux-gnueabi/libexpat.so;debug;optimized;/usr/lib/arm-linux-gnueabi/libnetcdf.so;/usr/lib/arm-linux-gnueabi/libnetcdf_c++.so;/usr/lib/arm-linux-gnueabi/hdf5/serial/libhdf5.so;/usr/lib/arm-linux-gnueabi/libpthread.so;/usr/lib/arm-linux-gnueabi/libsz.so;/usr/lib/arm-linux-gnueabi/libdl.so;/usr/lib/arm-linux-gnueabi/libproj.so;-lpangocairo-1.0;-lpango-1.0;-lgobject-2.0;-lglib-2.0;-lcairo " )

set( MAGICS_VERSION           "2.34.1" )
set( MAGICS_GIT_SHA1          "" )
set( MAGICS_GIT_SHA1_SHORT    "" )

### export include paths as absolute paths

set( MAGICS_INCLUDE_DIRS "" )
foreach( path ${MAGICS_SELF_INCLUDE_DIRS} )
  get_filename_component( abspath ${path} ABSOLUTE )
  list( APPEND MAGICS_INCLUDE_DIRS ${abspath} )
endforeach()
list( APPEND MAGICS_INCLUDE_DIRS ${MAGICS_TPL_INCLUDE_DIRS} )

### export definitions

set( MAGICS_DEFINITIONS      ${MAGICS_SELF_DEFINITIONS} ${MAGICS_TPL_DEFINITIONS} )

### export list of all libraries

set( MAGICS_LIBRARIES        ${MAGICS_SELF_LIBRARIES}   ${MAGICS_TPL_LIBRARIES}   )

### export the features provided by the package

set( MAGICS_FEATURES    "TESTS;ECCODES;BUFR;CAIRO;GEOTIFF;NETCDF;PYTHON;FORTRAN;METVIEW;QT5;PNG" )
foreach( _f ${MAGICS_FEATURES} )
  set( MAGICS_HAVE_${_f} 1 )
endforeach()

# Has this configuration been exported from a build tree?
set( MAGICS_IS_BUILD_DIR_EXPORT OFF )

if( EXISTS ${MAGICS_CMAKE_DIR}/magics-import.cmake )
  set( MAGICS_IMPORT_FILE "${MAGICS_CMAKE_DIR}/magics-import.cmake" )
  include( ${MAGICS_IMPORT_FILE} )
endif()

# here goes the imports of the TPL's

include( ${CMAKE_CURRENT_LIST_FILE}.tpls OPTIONAL )

# insert definitions for IMPORTED targets

if( NOT magics_BINARY_DIR )

  if( MAGICS_IS_BUILD_DIR_EXPORT )
    include( "/build/magics++-D1Lcu2/magics++-2.34.1/debian/build-py3/magics-targets.cmake" OPTIONAL )
  else()
    include( "${MAGICS_CMAKE_DIR}/magics-targets.cmake" OPTIONAL )
  endif()

endif()

# publish this file as imported

set( MAGICS_IMPORT_FILE ${CMAKE_CURRENT_LIST_FILE} )
mark_as_advanced( MAGICS_IMPORT_FILE )

# set magics_BASE_DIR for final installations or build directories

if( NOT magics )
  if( MAGICS_IS_BUILD_DIR_EXPORT )
    set( magics_BASE_DIR /build/magics++-D1Lcu2/magics++-2.34.1/debian/build-py3 )
  else()
    get_filename_component( abspath ${CMAKE_CURRENT_LIST_DIR}/../../.. ABSOLUTE )
    set( magics_BASE_DIR ${abspath} )
  endif()
endif()
